Learn R Programming

SVAlignR (version 0.9.2)

DeBruijn-class: Class "DeBruijn"

Description

Classes for contructing de Bruijn graphs from collections of long read sequences mappe over brakpoints.

Usage

deBruijn(rawseq, M)

Value

The deBruijn constructor returns a newly created object of the DeBruijn class.

Objects from the Class

Objects should be defined using the deBruijn constructor.

Arguments

rawseq

A character vecvtor of the long read sequences, expressed as hyphen-separated breakpoint ids.

M

An integer; the length of the motifs/words to be used in constructing the graph.

Slots

G:

An object of hhe igraph class

adjmat:

An adjacency matrix.

motifs:

A table of motifs/words.

Author

Kevin R. Coombes <krc@silicovore.com>