"DeBruijn"Classes for contructing de Bruijn graphs from collections of long read sequences mappe over brakpoints.
deBruijn(rawseq, M)The deBruijn constructor returns a newly created object of the
DeBruijn class.
Objects should be defined using the deBruijn constructor.
A character vecvtor of the long read sequences, expressed as hyphen-separated breakpoint ids.
An integer; the length of the motifs/words to be used in constructing the graph.
G:An object of hhe igraph class
adjmat:An adjacency matrix.
motifs:A table of motifs/words.
Kevin R. Coombes <krc@silicovore.com>